Function diem_sdk::crypto::noise::decrypted_len [−][src]
pub const fn decrypted_len(ciphertext_len: usize) -> usizeExpand description
A handy const fn to get the size of a plaintext from a ciphertext size
pub const fn decrypted_len(ciphertext_len: usize) -> usizeA handy const fn to get the size of a plaintext from a ciphertext size