Struct diem_sdk::crypto::noise::NoiseSession[][src]

pub struct NoiseSession { /* fields omitted */ }
A NoiseSession is produced after a successful Noise handshake, and can be use to encrypt and decrypt messages to the other peer.

Implementations

create a dummy session with 0 keys

obtain remote static public key

encrypts a message for the other peers (post-handshake) the function encrypts in place, and returns the authentication tag as result

decrypts a message from the other peer (post-handshake) the function decrypts in place, and returns a subslice without the auth tag